/*
 * libsyncml - A syncml protocol implementation
 * Copyright (C) 2005  Armin Bauer <armin.bauer@opensync.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; version 
 * 2.1 of the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
 *
 */

#ifndef _HTTP_CLIENT_H_
#define _HTTP_CLIENT_H_

typedef struct SmlTransportHttpClientConfig {
	int port;
	char *url;
	char *proxy;
	char *username;
	char *password;
	char *cafile;
} SmlTransportHttpClientConfig;

SmlBool smlTransportHttpClientNew(SmlTransport *tsp, SmlError **error);

SmlBool smlTransportHttpClientIsConnected(SmlTransport *tsp, SmlBool is_blocking, SmlError **error);

#endif //_HTTP_CLIENT_H_
